==> common_api-2.9.3.1-sources.jar: com/cloud/sdk/commonutil/util/MD5.java <==
package com.cloud.sdk.commonutil.util;

import android.text.TextUtils;

import java.security.MessageDigest;

/**
 * Created by wenshuai.liu on 2017/5/9.
 * ========================================
 * CopyRight (c) 2016 TRANSSION.Co.Ltd.
 * All rights reserved.
 */

public class MD5 {
    private static final String[] hexDigits = {"0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "a", "b", "c", "d", "e", "f"};

    private MD5() {
        throw new IllegalStateException("Utility class");
    }

    public static String byteArrayToHexString(byte[] b) {
        StringBuilder resultSb = new StringBuilder();
        for (int i = 0; i < b.length; i++) {
            resultSb.append(byteToHexString(b[i]));
        }
        return resultSb.toString();
    }

    private static String byteToHexString(byte b) {
        int n = b;
        if (n < 0) {
            n += 256;
        }
        int d1 = n / 16;
        int d2 = n % 16;
        return hexDigits[d1] + hexDigits[d2];
    }

    @SuppressWarnings("RedundantStringConstructorCall")
    public static String MD5Encode(String origin) {
        if (TextUtils.isEmpty(origin)) {
            return "";
        }

        String resultString = null;
        try {
            resultString = origin;
            MessageDigest md = MessageDigest.getInstance("MD5");
            resultString = byteArrayToHexString(md.digest(resultString
                    .getBytes()));
        } catch (Exception ex) {
            ex.printStackTrace();
        }
        return resultString;
    }
}

==> common_api-2.9.8.0-sources.jar: com/cloud/sdk/commonutil/util/MD5.java <==
package com.cloud.sdk.commonutil.util;

import android.text.TextUtils;
import android.util.Log;

import java.security.MessageDigest;

/**
 * Created by wenshuai.liu on 2017/5/9.
 * ========================================
 * CopyRight (c) 2016 TRANSSION.Co.Ltd.
 * All rights reserved.
 */

public class MD5 {
    private static final String TAG = "MD5";
    private static final String[] hexDigits = {"0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "a", "b", "c", "d", "e", "f"};

    private MD5() {
        throw new IllegalStateException("Utility class");
    }

    public static String byteArrayToHexString(byte[] b) {
        StringBuilder resultSb = new StringBuilder();
        for (int i = 0; i < b.length; i++) {
            resultSb.append(byteToHexString(b[i]));
        }
        return resultSb.toString();
    }

    private static String byteToHexString(byte b) {
        int n = b;
        if (n < 0) {
            n += 256;
        }
        int d1 = n / 16;
        int d2 = n % 16;
        return hexDigits[d1] + hexDigits[d2];
    }

    @SuppressWarnings("RedundantStringConstructorCall")
    public static String MD5Encode(String origin) {
        if (TextUtils.isEmpty(origin)) {
            return "";
        }

        String resultString = null;
        try {
            resultString = origin;
            MessageDigest md = MessageDigest.getInstance("MD5");
            resultString = byteArrayToHexString(md.digest(resultString
                    .getBytes()));
        } catch (Exception ex) {
            Log.e(TAG, Log.getStackTraceString(ex));
        }
        return resultString;
    }
}
